/*  screen.css - MoinMoin Default Styles

Copyright (c) 2001, 2002, 2003 by Juergen Hermann
*/

/* content styles */

body {
	margin:0;
}

.footnotes div {
	width: 5em;
	border-top: 1px solid #e5e5e5;
}

input {
    font-size: 1em;
    font-family: Arial, Lucida Grande, sans-serif;
}

textarea {
    font-size: 1em;
    font-family: Arial, sans-serif;
    color: #000
    background: #bbb
}

span.sep {
    display: none;
}

/* user interface styles */

#header {
    background: RGB(47,79,79);
    border-bottom: 1px solid RGB(106,90,205);
}

#logo {
    margin: 0;
    padding: 5px 10px;
    /* For text only logo */
    font-weight: bold;
    font-size: 24px;
    line-height: 1em;
    white-space: nowrap;
}

#logo img {
    vertical-align: left;
}

#logo a {
    color: RGB(106,90,205);  
    text-decoration: none;
}

#searchform {
    float: right;
    margin: 5px 10px 0 10px;
    padding: 0;
    white-space: nowrap;
}

*[dir="rtl"] #searchform {
    float: left;
}

#searchform form div {
    display: inline;
}

#page {
    margin: 10px 220px 10px 10px;
	padding: 15px 30px;
	border: 1px solid #9c9c9c;
	border-bottom: 2px solid #9c9c9c;
	background-color: #ccc;
}

#title h1 {
	margin: 0;
	padding:10px 0;
	font-size: 2em;
	line-height: 1.2em;
}

#title h1 a {
	text-decoration: none;
}

#sidebar {
	margin: 10px;
	float: right;
	clear: right;
	width: 200px;
	padding: 0;	
	font-size: 0.88em;
        /*
        background:RGB(47,79,79);
        */
}

.sidepanel {
	margin: 0 0 10px 0;
	float: right;
	width: 200px;	
	background: RGB( 20,  80, 120);
	border: 1px solid RGB(106,90,205);
	border-bottom: 2px solid RGB(106,90,205);
}

.sidepanel h1 {
	margin: 0;
	padding: 0.2em 10px;
	text-align:center;
	border: none;
        /*
	border-top: 1px solid white;
	border-bottom: 1pt solid #BFAE8F;
        */
	font-size: 1.2em;
        color:RGB(106,90,205);
	background: RGB(47,79,79);
}

.sidepanel h2 {
	margin: 0;
	padding: 0.2em 10px;
	font-size: 1.15em;
	border: none;
	color: black;
	background: #ccc;
}

.sidepanel ul {
	list-style-type: none;
	margin: 0;
	padding:0;
        background: #ccc;
}

.sidepanel li {
	margin: 0;
	padding:2px 10px;
	/*
        border-bottom: 1pt solid #BFAE8F;
        */
        background: #ccc;
}

.sidepanel li form {
	margin: 0;
}

.sidepanel a {
	text-decoration: none;
	display: block;
}

.sidepanel a:hover {
	text-decoration: underline;
}

#navibar li.current {
	border: none;
	background: RGB(67,99,99)
        color: white
}

.editbar form, .editbar form div {
    display: inline;
	margin: 0;
}

#credits, #version, #timings{
	float: right;
	clear: right;
	margin: 5px 0;
	width: 200px;
	padding: 0;
	list-style-type: none;
	text-align: center;
	font-size: 0.88em;
	color: gray;
}


#message {
	margin: 10px 220px 10px 10px;
	padding: 5px 10px;
	background-color: RGB(47,79,79);
	border: 1px solid RGB(106,90,205);
	border-bottom: 2px solid RGB(106,90,205);
}

#message p{
	margin: 5px 0;
	padding: 0;
	font-weight: bold;
}

#message div.buttons {
	font-weight: normal;
}

form.dialog {
    margin: 0 15px;
}

.dialog td {
    border: none;
    padding: 5px;
}

.dialog td.label {
    text-align: right;
    font-weight: bold;
    width: 25%;
}

*[dir="rtl"] .dialog td.label {
    text-align: left;
}

.dialog td.content input {
    width: 100%;
}

/* We use here dumb css1 ids becuase of IE suckiness */
#editor-textarea, #editor-comment {
    width: 100%;
}

#pagebottom {
	clear: both;
}

#preview {
	border: 2px solid RGB(106,90,205);
	padding: .5em;
        /*
	background: url(../img/draft.png);
        */
        background-image: url(../img/draft2.png);
        background-repeat: repeat-y;
        background-position: 50% 30%;
}

.diff {
	width:99%;
}

.diff-title {
	background-color: #C0C0C0;
}

.diff-added {
	background-color: #E0FFE0;
	vertical-align: sub;
}

.diff-removed {
	background-color: #FFFFE0;
	vertical-align: sub;
}

.diff-added span {
	background-color: #80FF80;
}

.diff-removed span {
	background-color: #FFFF80;
}

.searchresult dd span {
	font-weight: bold;
}

